@@ -585,10 +585,7 @@ def _handle_annotators(annotation: dt.Annotation, import_annotators: bool) -> Li
 
 
 def _get_annotation_data(
-    annotation: dt.AnnotationLike,
-    annotation_class_id: str,
-    attributes: dt.DictFreeForm,
-    data: dt.DictFreeForm,
+    annotation: dt.AnnotationLike, annotation_class_id: str, attributes: dt.DictFreeForm
 ) -> dt.DictFreeForm:
     annotation_class = annotation.annotation_class
     if isinstance(annotation, dt.VideoAnnotation):
@@ -639,7 +636,7 @@ def _import_annotations(
         annotation_type = annotation_class.annotation_internal_type or annotation_class.annotation_type
         annotation_class_id: str = remote_classes[annotation_type][annotation_class.name]
 
-        data = _get_annotation_data(annotation, annotation_class_id, attributes, annotation.data)
+        data = _get_annotation_data(annotation, annotation_class_id, attributes)
 
         actors: List[dt.DictFreeForm] = []
         actors.extend(_handle_annotators(annotation, import_annotators))
